@@ -32,5 +32,19 @@ done
 PRGDIR=`dirname "$PRG"`
 #
 
-# call d2j_invoke.sh to setup java environment
-"$PRGDIR/d2j_invoke.sh" "com.googlecode.dex2jar.tools.DexRecomputeChecksum" "$@"
+_classpath="."
+if [ `uname -a | grep -i -c cygwin` -ne 0 ]; then # Cygwin, translate the path
+    for k in "$PRGDIR"/lib/*.jar
+    do
+        _classpath="${_classpath};`cygpath -w ${k}`"
+    done
+else
+    for k in "$PRGDIR"/lib/*.jar
+    do
+        _classpath="${_classpath}:${k}"
+    done
+fi
+
+JAVA_CMD=$(javaPathHelper -c dex2jar)
+
+${JAVA_CMD} -Xms512m -Xmx2048m -classpath "${_classpath}" "com.googlecode.dex2jar.tools.DexRecomputeChecksum" "$@"
